@@ -70,10 +70,18 @@ juice.ModelRecipe <- function(x, ...) {
 }
 
 
+prep.ModelFrame <- function(x, ...) x
+
+
 prep.ModelRecipe <- function(x, ...) {
   if (!recipes::fully_trained(x)) {
-    new(class(x), prep(as(x, "recipe"), retain = FALSE))
-  } else x
+    x <- new(class(x), prep(as(x, "recipe"), retain = FALSE))
+    case_name_var <- "(names)"
+    x$template[[case_name_var]] <- as.character(x$template[[case_name_var]])
+    x$orig_lvls[[case_name_var]] <- list(values = NA, ordered = NA)
+    x$levels[[case_name_var]] <- x$orig_lvls[[case_name_var]]
+  }
+  x
 }
 
 
